@@ -1,12 +1,10 @@
 #!/bin/bash -xe
 # script to trigger rhpkg (no assets to fetch)
+#
 scratchFlag=""
 targetFlag=""
 doRhpkgContainerBuild=1
 forceBuild=0
-# NOTE: --pull-assets (-p) flag uses opposite behaviour to some other get-sources.sh scripts;
-# here we want to collect assets during sync-to-downsteam (using get-sources.sh -n -p)
-# so that rhpkg build is simply a brew wrapper (using get-sources.sh -f)
 
 while [[ "$#" -gt 0 ]]; do
 	case $1 in
@@ -26,9 +24,9 @@ done
 if [[ ${forceBuild} -eq 1 ]] || [[ ${doRhpkgContainerBuild} -eq 1 ]]; then
 	echo "[INFO] #0 Trigger container-build in current branch: rhpkg container-build ${scratchFlag} ${targetFlag}"
 	git status || true
-	tmpfile=$(mktemp) && rhpkg container-build ${scratchFlag} ${targetFlag} --nowait | tee 2>&1 $tmpfile
-	taskID=$(cat $tmpfile | grep "Created task:" | sed -e "s#Created task:##") && brew watch-logs $taskID | tee 2>&1 $tmpfile
-	ERRORS="$(grep "image build failed" $tmpfile)" && rm -f $tmpfile
+	tmpfile=$(mktemp) && rhpkg container-build ${scratchFlag} ${targetFlag} --nowait | tee 2>&1 "${tmpfile}"
+	taskID=$(cat "${tmpfile}" | grep "Created task:" | sed -e "s#Created task:##") && brew watch-logs $taskID | tee 2>&1 "${tmpfile}"
+	ERRORS="$(grep "image build failed" "${tmpfile}")" && rm -f "${tmpfile}"
 	if [[ "$ERRORS" != "" ]]; then echo "Brew build has failed:
 
 $ERRORS
