@@ -10,19 +10,17 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import { Brand, PageHeader } from '@patternfly/react-core';
+import { PageHeader } from '@patternfly/react-core';
 import { History } from 'history';
 import React from 'react';
-import { ThemeVariant } from '../themeVariant';
 import HeaderTools from './Tools';
 
 type Props = {
   history: History;
   isVisible: boolean;
-  logoUrl: string;
+  logo: React.ReactNode;
   logout: () => void;
   toggleNav: () => void;
-  changeTheme: (theme: ThemeVariant) => void;
 };
 type State = {
   isVisible: boolean;
@@ -50,7 +48,6 @@ export default class Header extends React.PureComponent<Props, State> {
   }
 
   public render(): React.ReactElement {
-    const logo = <Brand src={this.props.logoUrl} alt="Logo" />;
     const className = this.state.isVisible ? 'show-header' : 'hide-header';
 
     return (
@@ -58,7 +55,7 @@ export default class Header extends React.PureComponent<Props, State> {
         style={{ zIndex: 'inherit' }}
         className={className}
         logoComponent="div"
-        logo={logo}
+        logo={this.props.logo}
         showNavToggle={true}
         onNavToggle={() => this.toggleNav()}
         headerTools={
