@@ -22,13 +22,20 @@ export function buildStepName(
   //  - repo: means no devfile is found and default is generated
   //  - any other - devfile is found in repository as filename from the value
   const { source } = factoryResolver;
+  const { devfileV2 } = factoryResolverConverted;
+
+  const devfileName =
+    devfileV2.metadata.name !== undefined
+      ? `name "${devfileV2.metadata.name}"`
+      : `generateName "${devfileV2.metadata.generateName}"`;
   let newTitle = '';
+
   if (!source) {
-    newTitle += `Devfile loaded from ${sourceUrl}.`;
+    newTitle += `Devfile found with ${devfileName}.`;
   } else if (source === 'repo') {
     newTitle = `Devfile could not be found in ${sourceUrl}. Applying the default configuration.`;
   } else {
-    newTitle = `Devfile found in repo ${sourceUrl} as '${source}'.`;
+    newTitle = `Devfile found with ${devfileName}.`;
     if (factoryResolverConverted.isConverted) {
       newTitle += ` Devfile version 1 found, converting it to devfile version 2.`;
     }
