@@ -34,7 +34,7 @@ jest.mock('../../../components/WorkspaceProgress');
 jest.mock('../../../components/WorkspaceLogs');
 jest.mock('../../../components/WorkspaceEvents');
 
-const { createSnapshot, renderComponent } = getComponentRenderer(getComponent);
+const { renderComponent } = getComponentRenderer(getComponent);
 
 const mockOnTabChange = jest.fn();
 
@@ -68,25 +68,6 @@ describe('Loader page', () => {
     jest.clearAllMocks();
   });
 
-  test('snapshot, creating workspace flow', () => {
-    const emptyStore = new FakeStoreBuilder().build();
-    const snapshot = createSnapshot(emptyStore, {
-      history,
-      tabParam,
-      workspace: undefined,
-    });
-    expect(snapshot.toJSON()).toMatchSnapshot();
-  });
-
-  test('snapshot, starting workspace flow', () => {
-    const snapshot = createSnapshot(store, {
-      history,
-      tabParam,
-      workspace,
-    });
-    expect(snapshot.toJSON()).toMatchSnapshot();
-  });
-
   it('should handle tab click', () => {
     renderComponent(store, {
       history,
@@ -94,7 +75,7 @@ describe('Loader page', () => {
       workspace,
     });
 
-    const tabButtonLogs = screen.getByRole('button', { name: 'Logs' });
+    const tabButtonLogs = screen.getByRole('tab', { name: 'Logs' });
     userEvent.click(tabButtonLogs);
 
     expect(mockOnTabChange).toHaveBeenCalledWith(LoaderTab.Logs);
