@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -23,6 +23,8 @@ export async function fetchUserProfile(namespace: string): Promise<api.IUserProf
     const response = await axios.get<api.IUserProfile>(url);
     return response.data;
   } catch (e) {
-    throw `Failed to fetch the user profile data. ${common.helpers.errors.getMessage(e)}`;
+    throw new Error(
+      `Failed to fetch the user profile data. ${common.helpers.errors.getMessage(e)}`,
+    );
   }
 }
